from piezas import Piezas
from colisiones import Colisiones
from fisica import ColisionesFisicas


def ejecutar():
    print "asdasd"
